Previous versions
=================

Online documentation of previous Expyriment versions is available for:

- `Expyriment 0.6.3 <http://docs.expyriment.org/old/0.6.3>`_
- `Expyriment 0.6.4 <http://docs.expyriment.org/old/0.6.4>`_
- `Expyriment 0.7.0 <http://docs.expyriment.org/old/0.7.0>`_
- `Expyriment 0.8.0 <http://docs.expyriment.org/old/0.8.0>`_
- `Expyriment 0.9.0 <http://docs.expyriment.org/old/0.9.0>`_
